import type { MaintOrditmVO } from './model';

import type { ID, IDS, PageResult } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  maintOrditmExport = '/eims/maintOrditm/export',
  maintOrditmList = '/eims/maintOrditm/list',
  root = '/eims/maintOrditm'
}

/**
 * 查询工单条目列表
 * @param query
 * @returns {*}
 */

export function listMaintOrditm(params?: any) {
  return requestClient.get<PageResult<MaintOrditmVO>>(Api.maintOrditmList, { params });
}

/**
 * 查询工单条目详细
 * @param maintOrditmId
 */
export function getMaintOrditm(maintOrditmId: ID) {
  return requestClient.get<MaintOrditmVO>(`${Api.root}/${maintOrditmId}`);
}

/**
 * 新增工单条目
 * @param data
 */
export function addMaintOrditm(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改工单条目
 * @param data
 */
export function updateMaintOrditm(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除工单条目
 * @param maintOrditmId
 */
export function delMaintOrditm(maintOrditmId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${maintOrditmId}`);
}
/**
 * 导出
 * @param
 */
export function maintOrditmExport(data: any) {
  return commonExport(Api.maintOrditmExport, data);
}
